import dynamic from "next/dynamic";

const OfficeMap = dynamic(() => import("../components/map"), {
  ssr: false,
});

import Image from "next/image";
import { useRouter } from "next/router";

import { useTranslation } from "next-i18next";

import parse from "html-react-parser";

import { Alert, Button, Card, Grid, Space } from "@mantine/core";

import { Icon, ICONS } from "vseth-canine-ui";

import ContactForm from "../components/contactForm";

import board from "../content/board.json";
import about from "../content/about.json";

export default function About() {
  const { t } = useTranslation("common");
  const { locale } = useRouter();

  return (
    <>
      <h1>{t("about")}</h1>

      <Grid style={{ justifyContent: "center" }}>
        {board.map((entry) => (
          <Grid.Col md={3} sm={4} xs={6}>
            <Card shadow="sm" radius="md" withBorder>
              <Card.Section
                style={{
                  position: "relative",
                  aspectRatio: "1/1",
                  overflow: "hidden",
                  marginBottom: "16px",
                  backgroundColor: "#244471",
                }}
              >
                <Image
                  src={entry.image}
                  width={0}
                  height={0}
                  sizes="100vw"
                  style={{ width: "100%", height: "auto" }}
                  alt={entry.name}
                />
              </Card.Section>
              <h2 style={{ margin: 0 }}>{entry.name}</h2>
              <p>{entry.role[locale || "en"]}</p>
              <Space h="sm" />
              <a href={"mailto:" + entry.mail}>
                <Button leftIcon={<Icon icon={ICONS.EMAIL} color="white" />}>
                  {t("contact")}
                </Button>
              </a>
            </Card>
          </Grid.Col>
        ))}
      </Grid>

      <Space h="xl" />
      <Space h="xl" />
      <section id="address">
        <Grid>
          <Grid.Col md={4} sm={6} xs={12}>
            <Alert title={t("aboutUs")}>
              {about.description[locale || "en"]}
            </Alert>
            <Space h="md" />

            <b>TheAlternative</b>
            {about.address.map((line) => (
              <p>{line}</p>
            ))}

            <Space h="xs" />
            {/* stolen from here: https://stackoverflow.com/questions/33577448/is-there-a-way-to-do-array-join-in-react */}
            {about.links
              .map((link) => (
                <a target="_blank" href={link.url}>
                  {link.text}
                </a>
              ))
              .reduce(
                (acc, x) =>
                  acc === null ? (
                    x
                  ) : (
                    <>
                      {acc} | {x}
                    </>
                  ),
                null
              )}

            <Space h="xs" />
            <p>{parse(about.ssc[locale || "en"])}</p>
          </Grid.Col>
          <Grid.Col md={4} sm={6} xs={12}>
            <OfficeMap />
          </Grid.Col>
          <Grid.Col md={4} sm={6} xs={12}>
            <ContactForm />
          </Grid.Col>
        </Grid>
      </section>
    </>
  );
}
